@@ -1,8 +1,6 @@
 package Pithub::Base;
-$Pithub::Base::VERSION = '0.01025';
-BEGIN {
-  $Pithub::Base::AUTHORITY = 'cpan:PLU';
-}
+$Pithub::Base::VERSION = '0.01026';
+our $AUTHORITY = 'cpan:PLU';
 
 # ABSTRACT: Github v3 base class for all Pithub modules
 
@@ -15,6 +13,8 @@ use LWP::UserAgent;
 use Pithub::Result;
 use URI;
 
+with 'Pithub::Result::SharedCache';
+
 
 has 'auto_pagination' => (
     default => sub { 0 },
@@ -44,6 +44,7 @@ has 'per_page' => (
     clearer   => 'clear_per_page',
     is        => 'rw',
     predicate => 'has_per_page',
+    default   => 100,
     required  => 0,
 );
 
@@ -107,73 +108,49 @@ my @TOKEN_REQUIRED = (
 );
 
 my @TOKEN_REQUIRED_REGEXP = (
-    qr{^DELETE /gists/.*?$},
-    qr{^DELETE /gists/comments/.*?$},
-    qr{^DELETE /gists/[^/]+/star$},
-    qr{^DELETE /orgs/[^/]+/members/.*?$},
-    qr{^DELETE /orgs/[^/]+/public_members/.*?},
-    qr{^DELETE /repos/[^/]+/[^/]+/collaborators/.*?$},
-    qr{^DELETE /repos/[^/]+/[^/]+/comments/.*?$},
-    qr{^DELETE /repos/[^/]+/[^/]+/downloads/.*?$},
-    qr{^DELETE /repos/[^/]+/[^/]+/hooks/.*?$},
-    qr{^DELETE /repos/[^/]+/[^/]+/issues/comments/.*?$},
-    qr{^DELETE /repos/[^/]+/[^/]+/issues/[^/]+/labels$},
-    qr{^DELETE /repos/[^/]+/[^/]+/issues/[^/]+/labels/.*?$},
-    qr{^DELETE /repos/[^/]+/[^/]+/keys/.*?$},
-    qr{^DELETE /repos/[^/]+/[^/]+/labels/.*?$},
-    qr{^DELETE /repos/[^/]+/[^/]+/milestones/.*?$},
-    qr{^DELETE /repos/[^/]+/[^/]+/pulls/comments/.*?$},
-    qr{^DELETE /repos/[^/]+/[^/]+/releases/.*?$},
-    qr{^DELETE /repos/[^/]+/[^/]+/releases/assets/.*?$},
-    qr{^DELETE /teams/.*?$},
-    qr{^DELETE /teams/[^/]+/members/.*?$},
-    qr{^DELETE /teams/[^/]+/repos/.*?$},
-    qr{^DELETE /user/following/.*?$},
-    qr{^DELETE /user/keys/.*?$},
-    qr{^DELETE /user/starred/[^/]+/.*?$},
-    qr{^DELETE /user/watched/[^/]+/.*?$},
+    qr{^DELETE },
     qr{^GET /gists/starred$},
     qr{^GET /gists/[^/]+/star$},
     qr{^GET /issues$},
-    qr{^GET /orgs/[^/]+/members/.*?$},
+    qr{^GET /orgs/[^/]+/members/.*$},
     qr{^GET /orgs/[^/]+/teams$},
     qr{^GET /repos/[^/]+/[^/]+/collaborators$},
-    qr{^GET /repos/[^/]+/[^/]+/collaborators/.*?$},
+    qr{^GET /repos/[^/]+/[^/]+/collaborators/.*$},
     qr{^GET /repos/[^/]+/[^/]+/hooks$},
-    qr{^GET /repos/[^/]+/[^/]+/hooks/.*?$},
+    qr{^GET /repos/[^/]+/[^/]+/hooks/.*$},
     qr{^GET /repos/[^/]+/[^/]+/keys$},
-    qr{^GET /repos/[^/]+/[^/]+/keys/.*?$},
-    qr{^GET /teams/.*?$},
+    qr{^GET /repos/[^/]+/[^/]+/keys/.*$},
+    qr{^GET /teams/.*$},
     qr{^GET /teams/[^/]+/members$},
-    qr{^GET /teams/[^/]+/members/.*?$},
+    qr{^GET /teams/[^/]+/members/.*$},
     qr{^GET /teams/[^/]+/repos$},
-    qr{^GET /teams/[^/]+/repos/.*?$},
-    qr{^GET /user/following/.*?$},
-    qr{^GET /user/keys/.*?$},
+    qr{^GET /teams/[^/]+/repos/.*$},
+    qr{^GET /user/following/.*$},
+    qr{^GET /user/keys/.*$},
     qr{^GET /user/orgs$},
-    qr{^GET /user/starred/[^/]+/.*?$},
+    qr{^GET /user/starred/[^/]+/.*$},
     qr{^GET /user/watched$},
-    qr{^GET /user/watched/[^/]+/.*?$},
-    qr{^GET /users/[^/]+/events/orgs/.*?$},
-    qr{^PATCH /gists/.*?$},
-    qr{^PATCH /gists/comments/.*?$},
-    qr{^PATCH /orgs/.*?$},
-    qr{^PATCH /repos/[^/]+/.*?$},
-    qr{^PATCH /repos/[^/]+/[^/]+/comments/.*?$},
-    qr{^PATCH /repos/[^/]+/[^/]+/git/refs/.*?$},
-    qr{^PATCH /repos/[^/]+/[^/]+/hooks/.*?$},
-    qr{^PATCH /repos/[^/]+/[^/]+/issues/.*?$},
-    qr{^PATCH /repos/[^/]+/[^/]+/issues/comments/.*?$},
-    qr{^PATCH /repos/[^/]+/[^/]+/keys/.*?$},
-    qr{^PATCH /repos/[^/]+/[^/]+/labels/.*?$},
-    qr{^PATCH /repos/[^/]+/[^/]+/milestones/.*?$},
-    qr{^PATCH /repos/[^/]+/[^/]+/pulls/.*?$},
-    qr{^PATCH /repos/[^/]+/[^/]+/releases/.*?$},
-    qr{^PATCH /repos/[^/]+/[^/]+/pulls/comments/.*?$},
-    qr{^PATCH /teams/.*?$},
-    qr{^PATCH /user/keys/.*?$},
-    qr{^PATCH /user/repos/.*?$},
-    qr{^POST /repos/[^/]+/[^/]+/releases/[^/]+/assets.*?$},
+    qr{^GET /user/watched/[^/]+/.*$},
+    qr{^GET /users/[^/]+/events/orgs/.*$},
+    qr{^PATCH /gists/.*$},
+    qr{^PATCH /gists/[^/]+/comments/.*$},
+    qr{^PATCH /orgs/.*$},
+    qr{^PATCH /repos/[^/]+/.*$},
+    qr{^PATCH /repos/[^/]+/[^/]+/comments/.*$},
+    qr{^PATCH /repos/[^/]+/[^/]+/git/refs/.*$},
+    qr{^PATCH /repos/[^/]+/[^/]+/hooks/.*$},
+    qr{^PATCH /repos/[^/]+/[^/]+/issues/.*$},
+    qr{^PATCH /repos/[^/]+/[^/]+/issues/comments/.*$},
+    qr{^PATCH /repos/[^/]+/[^/]+/keys/.*$},
+    qr{^PATCH /repos/[^/]+/[^/]+/labels/.*$},
+    qr{^PATCH /repos/[^/]+/[^/]+/milestones/.*$},
+    qr{^PATCH /repos/[^/]+/[^/]+/pulls/.*$},
+    qr{^PATCH /repos/[^/]+/[^/]+/releases/.*$},
+    qr{^PATCH /repos/[^/]+/[^/]+/pulls/comments/.*$},
+    qr{^PATCH /teams/.*$},
+    qr{^PATCH /user/keys/.*$},
+    qr{^PATCH /user/repos/.*$},
+    qr{^POST /repos/[^/]+/[^/]+/releases/[^/]+/assets.*$},
     qr{^POST /gists/[^/]+/comments$},
     qr{^POST /orgs/[^/]+/repos$},
     qr{^POST /orgs/[^/]+/teams$},
@@ -197,15 +174,15 @@ my @TOKEN_REQUIRED_REGEXP = (
     qr{^POST /repos/[^/]+/[^/]+/releases$},
     qr{^POST /repos/[^/]+/[^/]+/pulls/[^/]+/comments$},
     qr{^PUT /gists/[^/]+/star$},
-    qr{^PUT /orgs/[^/]+/public_members/.*?$},
-    qr{^PUT /repos/[^/]+/[^/]+/collaborators/.*?$},
+    qr{^PUT /orgs/[^/]+/public_members/.*$},
+    qr{^PUT /repos/[^/]+/[^/]+/collaborators/.*$},
     qr{^PUT /repos/[^/]+/[^/]+/issues/[^/]+/labels$},
     qr{^PUT /repos/[^/]+/[^/]+/pulls/[^/]+/merge$},
-    qr{^PUT /teams/[^/]+/members/.*?$},
-    qr{^PUT /teams/[^/]+/repos/.*?$},
-    qr{^PUT /user/following/.*?$},
-    qr{^PUT /user/starred/[^/]+/.*?$},
-    qr{^PUT /user/watched/[^/]+/.*?$},
+    qr{^PUT /teams/[^/]+/members/.*$},
+    qr{^PUT /teams/[^/]+/repos/.*$},
+    qr{^PUT /user/following/.*$},
+    qr{^PUT /user/starred/[^/]+/.*$},
+    qr{^PUT /user/watched/[^/]+/.*$},
 );
 
 
@@ -256,7 +233,8 @@ sub request {
         my %query = ( $request->uri->query_form, %$params );
         $request->uri->query_form(%query);
     }
-    my $response = $self->ua->request($request);
+
+    my $response = $self->_make_request($request);
 
     return Pithub::Result->new(
         auto_pagination => $self->auto_pagination,
@@ -266,6 +244,31 @@ sub request {
 }
 
 
+sub _make_request {
+    my($self, $request) = @_;
+
+    if( my $cached_response = $self->shared_cache->get($request->uri) ) {
+        # Add the If-None-Match header from the cache's ETag
+        # and make the request
+        $request->header( "If-None-Match" => $cached_response->header("ETag") );
+        my $response = $self->ua->request($request);
+
+        # Got 304 Not Modified, cache is still valid
+        return $cached_response if ($response->code || 0) == 304;
+
+        # The response changed, cache it and return it.
+        $self->shared_cache->set( $request->uri, $response );
+        return $response;
+    }
+    else {
+        my $response = $self->ua->request($request);
+        $self->shared_cache->set( $request->uri, $response );
+        return $response;
+    }
+}
+
+
+
 sub has_token {
     my ($self, $request) = @_;
 
@@ -296,30 +299,23 @@ sub _get_user_repo_args {
 }
 
 sub _create_instance {
-    my ( $self, $class ) = @_;
+    my ( $self, $class, @args ) = @_;
+
     my %args = (
         api_uri         => $self->api_uri,
         auto_pagination => $self->auto_pagination,
         ua              => $self->ua,
+        @args
     );
-    if ( $self->has_repo ) {
-        $args{repo} = $self->repo;
-    }
-    if ( $self->has_token ) {
-        $args{token} = $self->token;
-    }
-    if ( $self->has_user ) {
-        $args{user} = $self->user;
-    }
-    if ( $self->has_per_page ) {
-        $args{per_page} = $self->per_page;
-    }
-    if ( $self->has_jsonp_callback ) {
-        $args{jsonp_callback} = $self->jsonp_callback;
-    }
-    if ( $self->has_prepare_request ) {
-        $args{prepare_request} = $self->prepare_request;
+
+    for my $attr (qw(repo token user per_page jsonp_callback prepare_request)) {
+        # Allow overrides to set attributes to undef
+        next if exists $args{$attr};
+
+        my $has_attr = "has_$attr";
+        $args{$attr} = $self->$attr if $self->$has_attr;
     }
+
     return $class->new(%args);
 }
 
@@ -348,12 +344,18 @@ sub _request_for {
     return $request;
 }
 
+my %TOKEN_REQUIRED = map { ($_ => 1) } @TOKEN_REQUIRED;
 sub _token_required {
     my ( $self, $method, $path ) = @_;
-    return 1 if grep $_ eq "${method} ${path}", @TOKEN_REQUIRED;
+
+    my $key = "${method} ${path}";
+
+    return 1 if $TOKEN_REQUIRED{$key};
+
     foreach my $regexp (@TOKEN_REQUIRED_REGEXP) {
-        return 1 if "${method} ${path}" =~ /$regexp/;
+        return 1 if $key =~ /$regexp/;
     }
+
     return 0;
 }
 
@@ -402,7 +404,7 @@ Pithub::Base - Github v3 base class for all Pithub modules
 
 =head1 VERSION
 
-version 0.01025
+version 0.01026
 
 =head1 DESCRIPTION
 
@@ -411,8 +413,8 @@ L<Pithub::Base>, even L<Pithub> itself. So all
 L<attributes|/ATTRIBUTES> listed here can either be set in the
 constructor or via the setter on the objects.
 
-If any attribute is set on a L<Pithub> object, it gets
-automatically set on objects, that get created by a method call on
+If any attribute is set on a L<Pithub> object it gets
+automatically set on objects that get created by a method call on
 the L<Pithub> object. This is very convenient for attributes like
 the L</token> or the L</user> and L</repo> attributes.
 
@@ -424,6 +426,13 @@ object of L<Pithub::Repos> where you set the L</user> and L</repo>
 attribute in the constructor, this will also be set once you
 get to the L<Pithub::Repos::Keys> object via the C<< keys >> method.
 
+Attributes passed along from the parent can be changed in the method
+call.
+
+    my $p = Pithub->new( per_page => 50 );
+    my $r1 = $p->repos;                         # $r->per_page == 50
+    my $r2 = $p->repos( per_page => 100 );      # $r->per_page == 100
+
 Examples:
 
     # just to demonstrate the "magic"
@@ -454,6 +463,8 @@ Examples:
 
 =head2 auto_pagination
 
+Off by default.
+
 See also: L<Pithub::Result/auto_pagination>.
 
 =head2 api_uri
@@ -527,17 +538,22 @@ B<has_jsonp_callback>: check if the jsonp_callback attribute is set
 
 =head2 per_page
 
-By default undef, so it defaults to Github's default. See also:
-L<http://developer.github.com/v3/#pagination>.
+Controls how many items are fetched per API call, aka "page".  See
+also: L<http://developer.github.com/v3/#pagination> and
+L</auto_pagination>.
+
+To minimize the number of API calls to get a complete listing, this
+defaults to the maximum allowed by Github, which is currently 100.
+This may change in the future if Github changes their maximum.
 
 Examples:
 
-    my $users = Pithub::Users->new( per_page => 100 );
+    my $users = Pithub::Users->new( per_page => 30 );
 
     # ... is the same as ...
 
     my $users = Pithub::Users->new;
-    $users->per_page(100);
+    $users->per_page(30);
 
 There are two helper methods:
 
