@@ -1,8 +1,6 @@
 package Pithub::Events;
-$Pithub::Events::VERSION = '0.01025';
-BEGIN {
-  $Pithub::Events::AUTHORITY = 'cpan:PLU';
-}
+$Pithub::Events::VERSION = '0.01026';
+our $AUTHORITY = 'cpan:PLU';
 
 # ABSTRACT: Github v3 Events API
 
@@ -120,7 +118,7 @@ Pithub::Events - Github v3 Events API
 
 =head1 VERSION
 
-version 0.01025
+version 0.01026
 
 =head1 METHODS
 
