@@ -1,8 +1,6 @@
 package Pithub::GitData::Tags;
-$Pithub::GitData::Tags::VERSION = '0.01025';
-BEGIN {
-  $Pithub::GitData::Tags::AUTHORITY = 'cpan:PLU';
-}
+$Pithub::GitData::Tags::VERSION = '0.01026';
+our $AUTHORITY = 'cpan:PLU';
 
 # ABSTRACT: Github v3 Git Data Tags API
 
@@ -48,7 +46,7 @@ Pithub::GitData::Tags - Github v3 Git Data Tags API
 
 =head1 VERSION
 
-version 0.01025
+version 0.01026
 
 =head1 DESCRIPTION
 
