@@ -1,8 +1,6 @@
 package Pithub::Issues::Assignees;
-$Pithub::Issues::Assignees::VERSION = '0.01025';
-BEGIN {
-  $Pithub::Issues::Assignees::AUTHORITY = 'cpan:PLU';
-}
+$Pithub::Issues::Assignees::VERSION = '0.01026';
+our $AUTHORITY = 'cpan:PLU';
 
 # ABSTRACT: Github v3 Issue Assignees API
 
@@ -47,7 +45,7 @@ Pithub::Issues::Assignees - Github v3 Issue Assignees API
 
 =head1 VERSION
 
-version 0.01025
+version 0.01026
 
 =head1 METHODS
 
