@@ -1,8 +1,6 @@
 package Pithub::Issues::Events;
-$Pithub::Issues::Events::VERSION = '0.01025';
-BEGIN {
-  $Pithub::Issues::Events::AUTHORITY = 'cpan:PLU';
-}
+$Pithub::Issues::Events::VERSION = '0.01026';
+our $AUTHORITY = 'cpan:PLU';
 
 # ABSTRACT: Github v3 Issue Events API
 
@@ -54,7 +52,7 @@ Pithub::Issues::Events - Github v3 Issue Events API
 
 =head1 VERSION
 
-version 0.01025
+version 0.01026
 
 =head1 METHODS
 
