@@ -1,8 +1,6 @@
 package Pithub::PullRequests::Comments;
-$Pithub::PullRequests::Comments::VERSION = '0.01025';
-BEGIN {
-  $Pithub::PullRequests::Comments::AUTHORITY = 'cpan:PLU';
-}
+$Pithub::PullRequests::Comments::VERSION = '0.01026';
+our $AUTHORITY = 'cpan:PLU';
 
 # ABSTRACT: Github v3 Pull Request Comments API
 
@@ -86,7 +84,7 @@ Pithub::PullRequests::Comments - Github v3 Pull Request Comments API
 
 =head1 VERSION
 
-version 0.01025
+version 0.01026
 
 =head1 METHODS
 
