@@ -1,8 +1,6 @@
 package Pithub::Repos::Hooks;
-$Pithub::Repos::Hooks::VERSION = '0.01025';
-BEGIN {
-  $Pithub::Repos::Hooks::AUTHORITY = 'cpan:PLU';
-}
+$Pithub::Repos::Hooks::VERSION = '0.01026';
+our $AUTHORITY = 'cpan:PLU';
 
 # ABSTRACT: Github v3 Repo Hooks API
 
@@ -96,7 +94,7 @@ Pithub::Repos::Hooks - Github v3 Repo Hooks API
 
 =head1 VERSION
 
-version 0.01025
+version 0.01026
 
 =head1 METHODS
 
