@@ -1,8 +1,6 @@
 package Pithub::Repos::Starring;
-$Pithub::Repos::Starring::VERSION = '0.01025';
-BEGIN {
-  $Pithub::Repos::Starring::AUTHORITY = 'cpan:PLU';
-}
+$Pithub::Repos::Starring::VERSION = '0.01026';
+our $AUTHORITY = 'cpan:PLU';
 
 # ABSTRACT: Github v3 Repo Starring API
 
@@ -85,7 +83,7 @@ Pithub::Repos::Starring - Github v3 Repo Starring API
 
 =head1 VERSION
 
-version 0.01025
+version 0.01026
 
 =head1 METHODS
 
