@@ -1,8 +1,6 @@
 package Pithub::Repos::Stats;
-$Pithub::Repos::Stats::VERSION = '0.01025';
-BEGIN {
-  $Pithub::Repos::Stats::AUTHORITY = 'cpan:PLU';
-}
+$Pithub::Repos::Stats::VERSION = '0.01026';
+our $AUTHORITY = 'cpan:PLU';
 
 # ABSTRACT: Github v3 repos / stats API
 
@@ -53,7 +51,7 @@ Pithub::Repos::Stats - Github v3 repos / stats API
 
 =head1 VERSION
 
-version 0.01025
+version 0.01026
 
 =head1 METHODS
 
