@@ -1,8 +1,6 @@
 package Pithub::Repos::Statuses;
-$Pithub::Repos::Statuses::VERSION = '0.01025';
-BEGIN {
-  $Pithub::Repos::Statuses::AUTHORITY = 'cpan:PLU';
-}
+$Pithub::Repos::Statuses::VERSION = '0.01026';
+our $AUTHORITY = 'cpan:PLU';
 
 # ABSTRACT:  Github v3 repos / statuses API
 
@@ -66,7 +64,7 @@ Pithub::Repos::Statuses - Github v3 repos / statuses API
 
 =head1 VERSION
 
-version 0.01025
+version 0.01026
 
 =head1 METHODS
 
