@@ -1,8 +1,6 @@
 package Pithub::Result;
-$Pithub::Result::VERSION = '0.01025';
-BEGIN {
-  $Pithub::Result::AUTHORITY = 'cpan:PLU';
-}
+$Pithub::Result::VERSION = '0.01026';
+our $AUTHORITY = 'cpan:PLU';
 
 # ABSTRACT: Github v3 result object
 
@@ -70,6 +68,7 @@ has 'response' => (
     required => 1,
 );
 
+
 # required for next_page etc
 has '_request' => (
     is       => 'ro',
@@ -189,6 +188,12 @@ sub prev_page {
 }
 
 
+sub etag {
+    my ($self) = @_;
+    return $self->response->header('ETag');
+}
+
+
 sub ratelimit {
     my ($self) = @_;
     return $self->response->header('X-RateLimit-Limit');
@@ -292,7 +297,7 @@ Pithub::Result - Github v3 result object
 
 =head1 VERSION
 
-version 0.01025
+version 0.01026
 
 =head1 DESCRIPTION
 
@@ -366,6 +371,23 @@ The L<HTTP::Response> object.
 
 =head1 METHODS
 
+=head2 raw_content
+
+Returns the content of the API response as a string, it will probably
+be JSON.
+
+=head2 request
+
+Returns the L<HTTP::Request> object used to make the API call.
+
+=head2 code
+
+Returns the HTTP code from the API call.
+
+=head2 success
+
+Returns whether the API call was successful.
+
 =head2 count
 
 Returns the count of the elements in L</content>. If the result is
@@ -471,6 +493,10 @@ L</auto_pagination>.
 
 =back
 
+=head2 etag
+
+Returns the value of the C<< ETag >> http header.
+
 =head2 ratelimit
 
 Returns the value of the C<< X-Ratelimit-Limit >> http header.
